@@ -1,6 +1,6 @@
 /*
   Licensed under the GNU Public License.
-  Copyright (C) 1998-2001 by Thomas M. Vier, Jr. All Rights Reserved.
+  Copyright (C) 1998-2003 by Thomas M. Vier, Jr. All Rights Reserved.
 
   wipe is free software.
   See LICENSE for more information.
@@ -22,9 +22,13 @@
 
 #ifdef HAVE_STDINT_H
 # include "stdint.h"
+#else
+# ifndef LINUX
+#  define u_int32_t uint32_t
+# endif
 #endif
 
-typedef u_int32_t urand_t;
+typedef u_int32_t u_rand_t;
 
 #ifndef UINT32_MAX
 # define UINT32_MAX ULONG_MAX
@@ -34,5 +38,5 @@ typedef u_int32_t urand_t;
 
 public int rand_init(void);
 public int prng_seed(void);
-public urand_t prng_get_urand(void);
-public void prng_fillbuf(const int seclevel, urand_t *buf, size_t size);
+public u_rand_t prng_get_rand(void);
+public void prng_fillbuf(const int seclevel, u_rand_t *buf, size_t size);
